#version 130
#extension GL_EXT_gpu_shader3 : enable
#extension GL_EXT_gpu_shader4 : enable

uniform sampler2D textureColorCurve;
uniform sampler2D textureImage[3];

uniform int dissolveMode;

uniform vec4 viewport;
uniform float baseDistance;

attribute float pointSize;
attribute float colorCurveS;
attribute float colorCurveT;
attribute float filterAlpha;
attribute int paramBit;

out vec3 positionIn;
out float pointSizeIn;
out vec4 colorIn;
out vec4 colorDiffuseIn;
out vec4 colorSpecularIn;
flat out int blendIn;
flat out int pseudoSphereIn;
flat out int textureImageIndexIn; // valid 0-3 not use if 4;

void main(void)
{
    positionIn = vec3(gl_ModelViewMatrix * gl_Vertex);

    vec4 baseColor = texture2D(textureColorCurve, vec2(colorCurveS, colorCurveT));
    baseColor[3] *= filterAlpha;

     vec4 colorDiffuseBase = texture2D(textureColorCurve, vec2(colorCurveS, colorCurveT+0.3333));
    vec4 colorSpecularBase = texture2D(textureColorCurve, vec2(colorCurveS, colorCurveT+0.6666));

    float alpha0 = baseColor[3];

    if (dissolveMode == 1)
	if (baseColor[3] < 0.015)
	    alpha0 = 1;
    
    if (dissolveMode == 2)
	alpha0 = 1;
    
    colorIn = baseColor; //vec4(baseColor[0] * alpha0, baseColor[1] * alpha0, baseColor[2] * alpha0, baseColor[3]);
    colorDiffuseIn = vec4(colorDiffuseBase[0] * alpha0, colorDiffuseBase[1] * alpha0, colorDiffuseBase[2] * alpha0, baseColor[3]);
    colorSpecularIn = vec4(colorSpecularBase[0] * alpha0, colorSpecularBase[1] * alpha0, colorSpecularBase[2] * alpha0, baseColor[3]);

    gl_Position = /*gl_ModelViewMatrix **/ gl_Vertex;
    pointSizeIn = pointSize;
    blendIn = paramBit % 2;
    pseudoSphereIn = (paramBit / 2) % 2;
    //boxPoint = (paramBit / 64) % 2;

    if ((paramBit / 8) % 2 == 0)
	textureImageIndexIn = 4;
    else
	textureImageIndexIn = (paramBit / 16) % 4;
}
